#
# spec file for package openstack-neutron-infoblox
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define component neutron-infoblox

%define version_unconverted 2.0.3.dev69

Name:           openstack-%{component}
Version:        2.0.3~a0~dev69
Release:        1.3
Summary:        Infoblox IPAM/DNS drivers for OpenStack Networking (Neutron)
License:        Apache-2.0
Group:          System/Management
Url:            https://launchpad.net/networking-infoblox/
Source0:        https://tarballs.openstack.org/networking-infoblox/networking-infoblox-master.tar.gz
Source1:        %{name}-ipam-agent.service
BuildRequires:  openstack-suse-macros
BuildRequires:  python-Babel >= 1.3
BuildRequires:  python-devel
BuildRequires:  python-infoblox-client >= 0.4.7
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-setuptools
# test requirements
BuildRequires:  openstack-neutron-test
BuildRequires:  python-coverage >= 3.6
BuildRequires:  python-oslosphinx >= 2.2.0
BuildRequires:  python-oslotest >= 1.2.0
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-sphinx >= 1.1.2
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testresources >= 0.2.4
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 0.9.36
Requires:       openstack-neutron
Requires:       python-Babel >= 1.3
Requires:       python-infoblox-client >= 0.4.15
Requires:       python-oslo.i18n >= 2.1.0
%{?systemd_requires}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%package doc
Summary:        Extra documentation for %{name}
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%package ipam-agent
Summary:        IPAM agent for %{name} plugin
Group:          System/Management
Requires:       %{name} = %{version}

%description
Contains Neutron drivers for integration with Infoblox grids for IPAM and DNS.

%description ipam-agent
Contains the IPAM agent service for %{name}

%description doc
This package contains extra documentation for %{name}.

%prep
%setup -q -n networking-infoblox-%{version_unconverted}

%build
python setup.py build
python setup.py build_sphinx
rm doc/build/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
### init script (systemd)
%__install -p -D -m 444 %{SOURCE1} %{buildroot}/%{_unitdir}/%{name}-ipam-agent.service
mkdir -p %{buildroot}%{_sbindir}
ln -s ../../%{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-ipam-agent
# We don't need this since we supply a systemd unit of our own
rm %{buildroot}/%{_prefix}/etc/init.d/infoblox-ipam-agent

%pre ipam-agent
%service_add_pre %{name}-ipam-agent.service

%post ipam-agent
%service_add_post %{name}-ipam-agent.service

%preun ipam-agent
%service_del_preun %{name}-ipam-agent.service

%postun ipam-agent
%service_del_postun %{name}-ipam-agent.service

%files
%defattr(-,root,root,-)
%doc LICENSE ChangeLog README.rst AUTHORS
%{python_sitelib}/*
%{_bindir}/create_ea_defs
%{_bindir}/infoblox_grid_sync

%files ipam-agent
%defattr(-,root,root,-)
%{_unitdir}/%{name}-ipam-agent.service
%{_sbindir}/rc%{name}-ipam-agent
%{_bindir}/infoblox-ipam-agent

%files doc
%defattr(-,root,root,-)
%doc LICENSE
%doc doc/build/html

%changelog
* Fri Aug 25 2017 tbechtold@suse.com
- Update to version networking-infoblox-2.0.3.dev69:
  * Changes doc for WAPI version support
  * "cloud\_data\_center\_id" cannot be 0
  * Updated Document for latest networking-infoblox release 8.0.1,9.0.1,10.0.0
  * Fix issue of infoblox client raising exception when dns\_support=False
  * Update infoblox-client requirement to 0.4.15
  * Handled exception in ip allocation for IPV6
  * Fixed issue related to A record creation failure with tenant\_info in DNS patter
  * Fixed issue which raises exception while running sync tool
  * Added validation for incorrect Domain Patterns
  * Zones is not adding in specified DNS View
  * Fixed issue related to syncing of port information in NIOS using sync tool
  * Fix issue in the rollback mechanism causes DNS zone delete in NIOS
  * Enabled domain-level authorization scope
  * Fix for sync tool failure after deleting a network from NIOS
  * Fix tox.ini to use upper-contraints.txt for dependency packages
  * Fix for DuplicateKey error when inserting to infoblox\_tenants table
  * Change Oslo.messaging version to pick <5.22.0
  * Fixed devstack and docs for Keystone V3 and TLS support
  * Fix data sync issues and Keystone v3 and ssl issues
  * Fix loading of neutron core plugin
  * Use neutron\_lib for db model\_base
  * Switch topic to topics and update module reference using latest lib
  * Describe new versioning scheme in README
  * Specify branch name in tox\_install.sh
  * Update db migration HEAD version
  * Use member\_ip to query for Grid Master
  * Delete DNS Name Server option if empty
  * LOG marker mismatch in notification.py
  * Fix empty DNS Name Server option
  * Update installation doc
* Fri Aug 25 2017 tbechtold@suse.com
- Remove python-discover from BuildRequires
* Fri Dec 16 2016 tbechtold@suse.com
- Update to version networking-infoblox-2.0.3.dev27:
  * Update infoblox-client requirement
  * Use model_base (and other things) from neutron-lib
  * Fix README
  * Fix IP allocator to reuse IP with same MAC
  * Changed the home-page link
  * Don't include openstack/common in flake8 exclude list
  * Drop MANIFEST.in - it's not needed by pbr
  * Update .coveragerc after the removal of openstack directory
  * Fix documentation link
  * keystone v3 support in syn_neutron_to_infoblox
  * TrivialFix: Remove logging import unused
  * Update Installation documentation
  * Use independent session for grid sync
  * additional EAs for zones
  * implement IPAM-DHCP only scenario
* Fri Sep  2 2016 johannes.grassler@suse.com
- Initial package.
